package org.greenstone.gsdl3.gs3build;

import java.io.File;
import org.greenstone.gsdl3.util.GSFile;

public class Create
{
    String gsdl3_home = null;
    String site_home = null;
    String collection = null;

    public Create(String gsdl3_home, String site, String collection)
    { 
	this.gsdl3_home = gsdl3_home;
	this.site_home = GSFile.siteHome(gsdl3_home, site);
	this.collection = collection;

	// check the site's collect directory
	File site_collect = new File(GSFile.collectDir(this.site_home));
	if (!site_collect.isDirectory()) {
	    System.err.println("Site's collect directory "+site_collect.getPath()+" doesn't exist. Please create it and try again");
	    System.exit(1);
	}

       	
    }
    
    public void makeCollection() {
	
	String coll_home = GSFile.collectionBaseDir(this.site_home, this.collection);
	File coll_dir_file = new File(coll_home);
	if (coll_dir_file.exists()) {
	    System.err.println("Collection directory ("+coll_dir_file.getPath()+") already exists, not creating it.");
	    System.exit(1);
	}
	createDirectory(coll_dir_file);
	createDirectory(new File(GSFile.collectionImportDir(coll_home)));
	createDirectory(new File(GSFile.collectionEtcDir(coll_home)));

	File config_template = new File(gsdl3_home + File.separator+ "resources"+File.separator + "xml"+File.separator+"collectionConfig.xml");
	if (!config_template.isFile()) {
	    System.err.println("Couldn't find the config file template "+config_template.getPath());
	    System.exit(1);
	}

	File coll_config = new File(GSFile.collectionConfigFile(coll_home));
	GSFile.copyFile(config_template, coll_config);

	System.err.println("New collection created in "+coll_home);
	System.err.println("Put source documents into import, set the collection's configuration in etc/collectionConfig.xml, then run gs3-build.sh (linux) or gs3-build (windows) to build the collection");
    }

    protected void createDirectory(File dir) {
	dir.mkdir();
	if (!dir.isDirectory()) {
	    System.err.println("Couldn't create directory "+dir.getPath());
	    System.exit(1);
	}
    }

    public static void main(String args[])
    { 
	String gsdl3_home = System.getProperty("GSDL3HOME");
	if (gsdl3_home == null) {
	    System.out.println("Error: Unable to locate GSDL3HOME");
	    System.exit(1);
	}

	int a = 0;
	String collection = null;
	String site = null;
	
	while (a < args.length) {
	    if (args[a].equals("-collect")) {
		if (a < args.length - 1 &&
		    args[a+1].charAt(0) != '-') {
		    
			collection = args[a+1];
			a ++;
		}
	    } else if (args[a].equals("-site")) {
		if (a < args.length - 1 &&
		    args[a+1].charAt(0) != '-') {
		    
		    site = args[a+1];
		    a ++;
		}
	    }
	    a ++;
	}
	
	if (site == null) {
	    
	    System.err.println("you must specify the site name");
	    System.exit(0);
	}
	if (collection == null) {
	    System.err.println("you must specify a collection");
	    System.exit(0);
	}
    
	Create c = new Create(gsdl3_home, site, collection);
	c.makeCollection();
	return;
    }
}
